@@ -28,10 +28,15 @@
 #include <getopt.h>
 #include <unistd.h>
 #include <locale.h>
-#include <iconv.h>
+#ifdef HAVE_LANGINFO_H
 #include <langinfo.h>
+#endif
 #include <limits.h>
 
+#if defined FALLBACK_CURSES || defined PINENTRY_CURSES || defined PINENTRY_GTK
+#include <iconv.h>
+#endif
+
 #include "assuan.h"
 #include "memory.h"
 #include "secmem-util.h"
@@ -65,11 +70,13 @@ struct pinentry pinentry =
   };
 
 
+
+#if defined FALLBACK_CURSES || defined PINENTRY_CURSES || defined PINENTRY_GTK
 char *
 pinentry_utf8_to_local (char *lc_ctype, char *text)
 {
   iconv_t cd;
-  char *input = text;
+  const char *input = text;
   size_t input_len = strlen (text) + 1;
   char *output;
   size_t output_len;
@@ -132,7 +139,7 @@ pinentry_local_to_utf8 (char *lc_ctype, char *text, int secure)
   char *old_ctype;
   char *source_encoding;
   iconv_t cd;
-  char *input = text;
+  const char *input = text;
   size_t input_len = strlen (text) + 1;
   char *output;
   size_t output_len;
@@ -192,6 +199,7 @@ pinentry_local_to_utf8 (char *lc_ctype, char *text, int secure)
     }
   return output_buf;
 }
+#endif
 
 /* Try to make room for at least LEN bytes in the pinentry.  Returns
    new buffer on success and 0 on failure or when the old buffer is
@@ -260,7 +268,7 @@ pinentry_have_display (int argc, char **argv)
 static void 
 usage (void)
 {
-  fprintf (stderr, "Usage: %s [OPTION]...\n"
+  fprintf (stdout, "Usage: %s [OPTION]...\n"
 "Ask securely for a secret and print it to stdout.\n"
 "\n"
 "      --display DISPLAY Set the X display\n"
@@ -670,8 +678,10 @@ pinentry_loop (void)
   ASSUAN_CONTEXT ctx;
 
   /* Extra check to make sure we have dropped privs. */
+#ifndef HAVE_DOSISH_SYSTEM
   if (getuid() != geteuid())
     abort ();
+#endif
 
   /* For now we use a simple pipe based server so that we can work
      from scripts.  We will later add options to run as a daemon and
